;; Generated package description from relint.el  -*- no-byte-compile: t -*-
(define-package "relint" "2.1.0.20250904.163151" "Elisp regexp mistake finder" '((xr "2.0") (emacs "27.1")) :commit "eb86eb54548c3d59c6a5b2a05ec6ae997ee48c05" :authors '(("Mattias Engdegård" . "mattias.engdegard@gmail.com")) :maintainer '("Mattias Engdegård" . "mattias.engdegard@gmail.com") :keywords '("lisp" "regexps") :url "https://github.com/mattiase/relint")
